# DataMaster_MCP 版本信息

## v1.0.2 (2025-01-24)

### 🐛 Bug修复

#### 依赖和导入问题修复
- **修复 SQLAlchemy 依赖缺失**: 将 SQLAlchemy 添加到核心依赖中，解决 uvx 运行时的 ModuleNotFoundError
- **修复 logger 未定义错误**: 将 logger 定义移到文件开头，解决 NameError 问题
- **优化导入顺序**: 确保所有依赖在使用前正确导入和初始化

### 🔧 技术改进
- 在 setup.py 中添加 `sqlalchemy>=2.0.0` 到核心依赖
- 重新组织 main.py 中的导入和初始化顺序
- 确保 uvx 运行环境的完整依赖支持

### ✅ 验证结果
- ✅ uvx 运行不再出现 SQLAlchemy 导入错误
- ✅ logger 初始化正常，无 NameError
- ✅ 所有核心功能正常运行
- ✅ 依赖管理更加稳定

---

## v1.0.1 (2025-01-24)

### 🐛 Bug修复

#### Excel导出功能修复
- **修复自动生成文件路径的扩展名错误**: 解决了当不指定文件路径时，Excel导出失败的问题
- **添加文件扩展名映射表**: 确保不同导出格式使用正确的文件扩展名
- **优化错误处理**: 改进了导出失败时的错误信息提示

### 🔧 技术改进
- 在`export_data`函数中添加`extension_map`映射表
- 修复文件路径生成逻辑，确保Excel文件使用`.xlsx`扩展名
- 保持向后兼容性，不影响指定路径的导出功能

### ✅ 验证结果
- ✅ 自动生成路径Excel导出正常
- ✅ 指定路径Excel导出正常  
- ✅ CSV和JSON导出功能未受影响
- ✅ 所有导出文件完整性验证通过

---

## v1.0.0 (2025-01-24)

### 🎉 正式版本发布

这是DataMaster_MCP的第一个正式版本，提供完整的数据分析功能。

### ✅ 核心功能

#### 数据导入导出
- **CSV文件导入**: 支持自动列类型识别和编码检测
- **Excel文件导入**: 支持多工作表和复杂格式
- **数据导出**: 支持Excel、CSV、JSON格式导出

#### 数据库连接
- **MySQL**: 完整的连接和查询支持
- **PostgreSQL**: 高性能数据库操作
- **MongoDB**: NoSQL数据库支持
- **SQLite**: 本地数据库存储

#### 数据分析
- **基本统计**: 均值、中位数、标准差、分位数
- **相关性分析**: 变量间关系分析
- **异常值检测**: 数据质量检查
- **缺失值分析**: 数据完整性评估
- **重复值检测**: 数据清洁度检查

#### 数据处理
- **数据过滤**: 条件筛选和查询
- **数据转换**: 类型转换和格式化
- **数据聚合**: 分组统计和汇总
- **数据清洗**: 去重和标准化
- **数据重塑**: 透视表和数据重组

#### API数据连接
- **RESTful API**: 支持GET、POST、PUT、DELETE
- **数据转换**: 自动JSON到表格转换
- **持久化存储**: API数据本地缓存
- **配置管理**: 灵活的API配置系统

#### 配置管理
- **数据库配置**: 统一的连接配置管理
- **API配置**: 端点和认证信息管理
- **环境配置**: 开发和生产环境分离

### 🧪 已验证功能

- ✅ CSV数据导入测试通过（5条记录）
- ✅ 数据查询分析正常（SQL执行）
- ✅ 数据统计分析正常（基本统计）
- ✅ 数据导出功能正常（Excel格式）
- ✅ 数据处理过滤正常（条件筛选）
- ✅ SQLite本地数据库操作正常
- ✅ 配置管理系统正常

### 📋 技术规格

- **Python版本**: 3.8+
- **核心依赖**: pandas, sqlalchemy, pymongo, psycopg2
- **数据库驱动**: pymysql, mysql-connector-python
- **文件格式**: CSV, Excel (xlsx), JSON
- **API协议**: HTTP/HTTPS, REST

### 🔧 安装要求

```bash
pip install -r requirements.txt
```

### 📖 使用文档

- [数据库连接功能使用指南](数据库连接功能使用指南.md)
- [API连接器功能使用指南](API连接器功能使用指南.md)
- [API数据存储功能使用指南](API数据存储功能使用指南.md)

### 🐛 已知限制

- 外部MySQL连接需要正确的服务器配置
- 大文件处理可能需要额外的内存优化
- API连接需要网络访问权限

### 🚀 下一版本计划

- 数据可视化功能
- 机器学习集成
- 实时数据流处理
- Web界面支持

---

**发布日期**: 2025年1月24日  
**提交哈希**: 1f8fac4  
**标签**: v1.0.0