# 📁 项目结构说明

## 🗂️ 目录结构

```
DataMaster_MCP/
├── 📄 README.md                 # 项目概览和快速开始
├── 📚 用户使用手册.md            # 完整的功能使用指南
├── 🛠️ 开发者文档.md             # 技术文档和AI使用指南
├── 📋 CHANGELOG.md              # 版本更新记录
├── 🏷️ VERSION.md                # 当前版本详情
├── ⚙️ main.py                   # MCP服务器主入口
├── 📦 requirements.txt          # 项目依赖包
├── 🔧 .env.example              # 环境变量模板
├── 📝 .gitignore                # Git忽略文件
├── 📁 config/                   # 配置管理模块
│   ├── 🔗 database_manager.py   # 数据库管理器
│   ├── ⚙️ config_manager.py     # 配置管理器
│   ├── 🌐 api_connector.py      # API连接器
│   ├── 💾 api_data_storage.py   # API数据存储
│   ├── 🔄 data_transformer.py   # 数据转换器
│   ├── 📊 api_config_manager.py # API配置管理
│   ├── 🗃️ database_config.json  # 数据库配置文件
│   ├── 🔌 api_config.json       # API配置文件
│   └── 📋 __init__.py           # 模块初始化
└── 📄 项目结构说明.md            # 本文件
```

## 📖 文档说明

### 🚀 新用户入门
1. **[README.md](README.md)** - 项目概览，快速了解功能和基本使用
2. **[用户使用手册.md](用户使用手册.md)** - 详细的功能使用指南，包含所有操作示例

### 🛠️ 开发者和AI
1. **[开发者文档.md](开发者文档.md)** - 技术架构、AI使用指南、修复记录
2. **[CHANGELOG.md](CHANGELOG.md)** - 版本更新历史
3. **[VERSION.md](VERSION.md)** - 当前版本功能详情

## 🔧 核心文件说明

### 主程序
- **main.py** - MCP服务器主入口，包含所有工具函数定义

### 配置管理
- **config/database_manager.py** - 数据库连接和查询管理
- **config/config_manager.py** - 配置文件管理和验证
- **config/api_connector.py** - API连接和数据获取
- **config/api_data_storage.py** - API数据持久化存储
- **config/data_transformer.py** - 数据格式转换

### 配置文件
- **config/database_config.json** - 数据库连接配置
- **config/api_config.json** - API端点配置
- **.env.example** - 环境变量模板（复制为.env使用）

## 🎯 使用建议

### 👤 普通用户
1. 阅读 **README.md** 了解项目
2. 参考 **用户使用手册.md** 学习具体操作
3. 查看 **VERSION.md** 了解当前功能

### 🤖 AI用户
1. 重点阅读 **开发者文档.md** 中的"AI工具使用指南"部分
2. 参考工具速查表和最佳实践
3. 注意"两步连接法"等设计特性

### 👨‍💻 开发者
1. 查看 **开发者文档.md** 了解架构设计
2. 阅读 **CHANGELOG.md** 了解修复历史
3. 参考代码规范和测试指南

## 📋 文件整理记录

### ✅ 已删除的重复文件
- 各种重复的使用指南文档
- 过时的修复报告
- 测试数据文件
- 临时脚本文件

### ✅ 已合并的内容
- 数据库连接指南 → 用户使用手册
- API连接器指南 → 用户使用手册
- AI工具指南 → 开发者文档
- 修复报告 → 开发者文档

### ✅ 新创建的文档
- **用户使用手册.md** - 综合的用户指南
- **开发者文档.md** - 技术和AI使用文档
- **项目结构说明.md** - 本文件

---

**整理完成时间**: 2025年1月24日  
**文档状态**: ✅ 完整清晰  
**维护建议**: 新功能添加时同步更新相关文档